@@ -134,9 +134,9 @@ def wf_bandstructure2D(structure, c=None):
     db_file = c.get("DB_FILE", DB_FILE)
     vdw_kernel = c.get("VDW_KERNEL_DIR", VDW_KERNEL_DIR)
 
-    mpr2d = MPScanRelaxSet2D(structure, force_gamma=True)
+    mpr2d = MPScanRelaxSet2D(structure, force_gamma=True, potcar_functional='PBE')
     '''check bandstructure.yaml'''
-    wf = get_wf(structure, "bandstructure.yaml", vis=MPScanRelaxSet2D(structure, force_gamma=True), \
+    wf = get_wf(structure, "bandstructure.yaml", vis=MPScanRelaxSet2D(structure, force_gamma=True, potcar_functional='PBE'), \
                 params=[{'vasp_input_set': mpr2d},{},{},{}], common_params={"vasp_cmd": vasp_cmd, "db_file": db_file,}) #"vdw_kernel_dir": vdw_kernel})
 
     wf = add_common_powerups(wf, c)
